@@ -615,9 +615,13 @@ class Game(object):
                     table.append(self.markup.color(color.upper()[0] + nums, color))
 
         if not table:
-            ret.public.append(self.markup.underline('Table: empty'))
+            ret.public.append(
+                self.markup.bold(
+                    self.markup.underline('Table: empty')))
         else:
-            ret.public.append(self.markup.underline('Table: %s' % ', '.join(table)))
+            ret.public.append(
+                self.markup.bold(
+                    self.markup.underline('Table: %s' % ', '.join(table))))
 
         ret.public.append('Notes: %s, Storms: %s, %d cards remaining.' %
                          (''.join(sorted(self.notes)), ''.join(sorted(self.storms)), len(self.deck)))
